@@ -16,12 +16,12 @@
 #   limitations under the License.
 #
 # ------------------------------------------------------------------------------
-"""CLI runner."""
+"""CLI runner."""  # pragma: no cover
 
-from autonomy.cli.core import cli
+from autonomy.cli.core import cli  # pragma: no cover
 
 
-if __name__ == "__main__":
-    cli(  # pragma: no cover  # type: ignore # pylint: disable = unexpected-keyword-arg, no-value-for-parameter
+if __name__ == "__main__":  # pragma: no cover
+    cli(  # type: ignore # pylint: disable = unexpected-keyword-arg, no-value-for-parameter
         prog_name="autonomy"
     )
