@@ -54,6 +54,7 @@ COMPONENT_CONFIGS: Dict = {
 }
 
 
+# TODO: how dpes this relate to `autonomy/services`? Unify
 class ServiceSpecification:
     """Class to assist with generating deployments."""
 
@@ -202,7 +203,10 @@ class BaseDeploymentGenerator:
 
     @abc.abstractmethod
     def generate(
-        self, image_version: Optional[str] = None
+        self,
+        image_version: Optional[str] = None,
+        use_hardhat: bool = False,
+        use_acn: bool = False,
     ) -> "BaseDeploymentGenerator":
         """Generate the deployment configuration."""
 
