@@ -30,6 +30,8 @@ from typing import Any, Callable, Dict, FrozenSet, Tuple, Type, cast
 from unittest import mock
 
 import pytest
+from aea_ledger_ethereum import EthereumCrypto
+
 from aea.common import Address
 from aea.configurations.base import ConnectionConfig
 from aea.connections.base import ConnectionStates
@@ -40,7 +42,6 @@ from aea.mail.base import Envelope
 from aea.multiplexer import Multiplexer
 from aea.protocols.base import Message
 from aea.protocols.dialogue.base import Dialogue, DialogueLabel, Dialogues
-from aea_ledger_ethereum import EthereumCrypto
 
 from packages.valory.connections.ledger.base import RequestDispatcher
 from packages.valory.connections.ledger.connection import LedgerConnection
@@ -81,7 +82,7 @@ class TestLedgerConnection:
 
         # setup a dummy ledger connection
         ledger_connection = LedgerConnection(
-            configuration=ConnectionConfig("ledger", "valory", "0.1.0"),
+            configuration=ConnectionConfig("ledger", "valory", "0.19.0"),
             data_dir="test_data_dir",
         )
 
@@ -435,7 +436,7 @@ class TestLedgerConnectionWithMultiplexer:
         cls.multiplexer = Multiplexer(
             [
                 LedgerConnectionWithDummyDispatcher(
-                    configuration=ConnectionConfig("ledger", "valory", "0.1.0"),
+                    configuration=ConnectionConfig("ledger", "valory", "0.19.0"),
                     data_dir="test_data_dir",
                 )
             ],
@@ -448,8 +449,9 @@ class TestLedgerConnectionWithMultiplexer:
             LedgerConnectionWithDummyDispatcher, cls.multiplexer.connections[0]
         )
         assert cls.ledger_connection._ledger_dispatcher is not None
-        cls.ledger_api_dialogues = (
-            cls.ledger_connection._ledger_dispatcher._ledger_api_dialogues
+        cls.ledger_api_dialogues = cast(
+            DummyLedgerApiDialogues,
+            cls.ledger_connection._ledger_dispatcher._ledger_api_dialogues,
         )
 
     @classmethod
