@@ -106,7 +106,9 @@ class _MetaRoundBehaviour(ABCMeta):
         """Check that matching rounds are: (1) unique across behaviour, and (2) covering."""
         round_to_behaviour: Dict[Type[AbstractRound], List[BehaviourType]] = {
             round_cls: []
-            for round_cls in behaviour_cls.abci_app_cls.get_all_round_classes()
+            for round_cls in behaviour_cls.abci_app_cls.get_all_round_classes(
+                behaviour_cls.is_background_behaviour_set
+            )
         }
 
         # check uniqueness
@@ -153,6 +155,7 @@ class AbstractRoundBehaviour(
     abci_app_cls: Type[AbciApp[EventType]]
     behaviours: AbstractSet[BehaviourType]
     initial_behaviour_cls: BehaviourType
+    background_behaviour_cls: Optional[BehaviourType] = None
 
     def __init__(self, **kwargs: Any) -> None:
         """Initialize the behaviour."""
@@ -165,6 +168,7 @@ class AbstractRoundBehaviour(
         ] = self._get_round_to_behaviour_mapping(self.behaviours)
 
         self.current_behaviour: Optional[BaseBehaviour] = None
+        self.background_behaviour: Optional[BaseBehaviour] = None
 
         # keep track of last round height so to detect changes
         self._last_round_height = 0
@@ -220,11 +224,23 @@ class AbstractRoundBehaviour(
             name=behaviour_cls.behaviour_id, skill_context=self.context
         )
 
+    @property
+    def is_background_behaviour_set(self) -> bool:
+        """Returns whether the background behaviour is set."""
+        return self.background_behaviour_cls is not None
+
     def setup(self) -> None:
-        """Set up the behaviour."""
+        """Set up the behaviours."""
         self.current_behaviour = self.instantiate_behaviour_cls(
             self.initial_behaviour_cls
         )
+        if self.is_background_behaviour_set:
+            self.background_behaviour_cls = cast(
+                Type[BaseBehaviour], self.background_behaviour_cls
+            )
+            self.background_behaviour = self.instantiate_behaviour_cls(
+                self.background_behaviour_cls
+            )
 
     def teardown(self) -> None:
         """Tear down the behaviour"""
@@ -237,11 +253,13 @@ class AbstractRoundBehaviour(
             return
 
         self.current_behaviour.act_wrapper()
-
         if self.current_behaviour.is_done():
             self.current_behaviour.clean_up()
             self.current_behaviour = None
 
+        if self.background_behaviour is not None:
+            self.background_behaviour.act_wrapper()
+
     def _process_current_round(self) -> None:
         """Process current ABCIApp round."""
         current_round_height = self.context.state.round_sequence.current_round_height
