@@ -29,7 +29,7 @@ parse_logs  # unused function (autonomy/cli/analyse.py:74)
 HARDHAT_IMAGE_NAME  # unused variable (autonomy/constants.py:25)
 is_transition_func_total  # unused method (autonomy/analyse/abci/app_spec.py:119)
 get_transitions  # unused method (autonomy/analyse/abci/app_spec.py:134)
-generat_abci_app_pecs  # unused function (autonomy/cli/analyse.py:52)
+generate_abci_app_specs  # unused function (autonomy/cli/analyse.py:52)
 check_abci_app_specs  # unused function (autonomy/cli/analyse.py:79)
 run_handler_check  # unused function (autonomy/cli/analyse.py:159)
 dump_json  # unused method (autonomy/analyse/abci/app_spec.py:159)
